.. _tutor_testenv:

TestEnv
=======

TestEnv extension provides testing environment for learning automated testing together with Yoda extension.

TestEnv provides simple CRM application with following interfaces:

* DB: interface to SQLite database
* REST: interface to REST services on web server
* SOAP: interface to SOAP services on web server
* GUI: interface to GUI application on web server

.. toctree::
   :maxdepth: 1
   
   tut1_db
   tut2_rest
   tut3_soap
   tut4_gui